/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: ScanFieldVisitor.java 2059 2007-11-22 17:22:33Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.annotations.analyzer;

import org.ow2.easybeans.asm.FieldVisitor;
import org.ow2.easybeans.deployment.annotations.JField;
import org.ow2.easybeans.deployment.annotations.metadata.ClassAnnotationMetadata;
import org.ow2.easybeans.deployment.annotations.metadata.FieldAnnotationMetadata;

/**
 * This classes analyses a given field and build/fill meta data information.
 * @author Florent Benoit
 */
public class ScanFieldVisitor extends ScanCommonVisitor<FieldAnnotationMetadata> implements FieldVisitor {


    /**
     * Class generated by the visitor which correspond to meta data contained in the parsed field.
     */
    private FieldAnnotationMetadata fieldAnnotationMetadata = null;


    /**
     * Parent of field annotation meta data that are built by this visitor.
     */
    private ClassAnnotationMetadata classAnnotationMetadata = null;

    /**
     * Constructor.
     * @param jField field object on which we set meta data.
     * @param classAnnotationMetadata the parent object on which add generated meta-data.
     */
    public ScanFieldVisitor(final JField jField, final ClassAnnotationMetadata classAnnotationMetadata) {

        // object build and to fill
        this.fieldAnnotationMetadata = new FieldAnnotationMetadata(jField, classAnnotationMetadata);

        // parent
        this.classAnnotationMetadata = classAnnotationMetadata;

        // list of visitors to use
        initVisitors();
    }

    /**
     * Build visitors used by this one.
     */
    private void initVisitors() {
        super.initVisitors(fieldAnnotationMetadata);

    }

    /**
     * Visits the end of the method. This method, which is the last one to be
     * called, is used to inform the visitor that all the annotations and
     * attributes of the method have been visited.
     */
    @Override
    public void visitEnd() {
        classAnnotationMetadata.addFieldAnnotationMetadata(fieldAnnotationMetadata);
    }

}
